<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-row :gutter="10">
          <el-col :span="9">
            <el-form-item label="采集时间">
              <el-date-picker v-model="querys[0].value" type="datetimerange" style="width: 100%"
                popper-class="dataTime-style" value-format="yyyy-MM-dd HH:mm:ss" range-separator="至"
                start-placeholder="开始日期" end-placeholder="结束日期">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="6">
            <el-form-item>
              <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
              <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel"></div>
      <el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight - 10" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="150" prop="deviceCode" label="设备标识" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="150" label="设备名称" show-overflow-tooltip>
          <template slot-scope="scope">
            <span class="active" @click="toDialog(scope.row.deviceName)">{{
              scope.row.deviceName
            }}</span>
          </template>
        </el-table-column>
        <el-table-column min-width="150" prop="collTime" label="采集时间" show-overflow-tooltip>
        </el-table-column>
        <!-- <el-table-column
          min-width="150"
          prop="createTime"
          label="入库时间"
          show-overflow-tooltip
        ></el-table-column> -->
        <el-table-column min-width="140" prop="alertName" label="报警状态" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="150" prop="lastActionName" label="升降柱最近的一次动作" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="100" prop="statusName" label="升降柱位置状态" show-overflow-tooltip>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
        :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <RealTimeMonitorDialog ref="RealTimeMonitorDialog"></RealTimeMonitorDialog>
  </div>
</template>

<script>
import {
  TableMixin
} from '@/mixins/tableMixin'
import RealTimeMonitorBiot from '@/api/device/RealTimeMonitorBiot.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import RealTimeMonitorDialog from '@/components/detailsDialog/RealTimeMonitorDialog.vue'

export default {
  name: 'RoadblockRealDataModel',
  components: {
    RealTimeMonitorDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      querys: [{
        group: 'main',
        operation: 'BETWEEN',
        parentGroup: '',
        property: 'coll_time_',
        relation: 'AND',
        value: ''
      }],
      sorter: [{
        direction: 'DESC',
        property: 'collTime'
      }],
      lastActionList: [], //升降柱最近的一次动作字典
      alertList: [], //报警状态字典
      statusList: '' //升降柱位置状态字典
    }
  },
  created() {
    this.lastActionList = dictUtils.getDictItemsFromCache('sjzzjdz')
    this.alertList = dictUtils.getDictItemsFromCache('bjzt')
    this.statusList = dictUtils.getDictItemsFromCache('sjzwzzt')
  },
  mounted() {
  },
  methods: {
    toDialog(name) {
      this.$refs.RealTimeMonitorDialog.add(name)
    },
    handleUpdate(row) {
      console.log(row)
    },
    clearQuerys() {
      this.querys[0].value = ''
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam = Object.assign(this.queryParam, {
        sorter: this.sorter
      })
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }

      RealTimeMonitorBiot.loadInfo(this.queryParam, (res) => {
        this.tableData = res.rows
        this.total = res.total
        this.$set(this.tableData)
        this.loading = false
        this.tableData.forEach((item) => {
          // 位置状态
          this.statusList.forEach((val) => {
            if (item.status && item.status == val.value) {
              item['statusName'] = val.name
            }
          })
          // 最近动作
          this.lastActionList.forEach((val) => {
            if (item.lastAction && item.lastAction == val.value) {
              item['lastActionName'] = val.name
            }
          })
          // 报警状态
          this.alertList.forEach((val) => {
            if (item.alert && item.alert == val.value) {
              item['alertName'] = val.name
            }
          })
        })
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.bbsl-table-content {
  position: relative;

  ::v-deep .el-pagination {
    position: absolute;
    right: 10px;
    bottom: 10px;
  }
}
</style>
<style lang="scss">
.dataTime-style {
  .el-time-spinner__item {
    height: auto !important;
    line-height: inherit;
  }

  .el-scrollbar__wrap {
    overflow: scroll !important;
  }
}

.active {
  color: #3399ff;
  cursor: pointer;
}
</style>
